@@ -30,6 +30,11 @@ import logging
 import requests
 import six
 from six import raise_from
+from urllib3.exceptions import (
+    NewConnectionError,
+    ConnectTimeoutError,
+    MaxRetryError,
+)
 
 from .catalog import CatalogController
 from .config import ConfigController
@@ -494,17 +499,21 @@ class ContainerPlatformClient(object):
             )  # 10 seconds
             response.raise_for_status()
 
-        except requests.exceptions.ConnectionError as e:
+        except (
+            requests.exceptions.ConnectionError,
+            NewConnectionError,
+            MaxRetryError,
+            ConnectTimeoutError,
+        ) as e:
             self.log.debug(
                 "RES: {} : {} {} {}".format("Login", "post", url, str(e))
             )
             if self.log.level == 10:  # "DEBUG"
-                msg = "Could not connect to controller."
+                # The error is already output to the log, so this message
+                # can be brief.
+                msg = "Could not connect to the controller."
             else:
-                msg = (
-                    "Could not connect to controller - set LOG_LEVEL=DEBUG to "
-                    "see more detail."
-                )
+                msg = "Could not connect to the controller.\n" + str(e)
             raise_from(
                 APIException(
                     message=msg, request_method="post", request_url=url,
